========================
Team and repository tags
========================

OpenStack Monasca-Events-Api
============================
OpenStack Monasca-Events-Api provides RESTful Api to collect events from OpenStack cloud.


OpenStack Monasca-Events-Api is distributed under the terms of the Apache License, Version 2.0.
The full terms and conditions of this license are detailed in the LICENSE file.

API
---

For the more information of OpenStack APIs, SDKs and CLIs, please see:

* `OpenStack Application Development <https://www.openstack.org/appdev/>`_
* `OpenStack Developer Documentation <https://developer.openstack.org/>`_

Developers
----------

For information on how to contribute to Monasca-events-api, please see the
contents of the CONTRIBUTING.rst.

Any new code must follow the development guidelines detailed
in the HACKING.rst file, and pass all unit tests as well as linters.

Further developer focused documentation is available at:

* `Monasca-events-api <https://docs.openstack.org/monasca-events-api/latest/>`_

Operators
---------

To learn how to deploy and configure OpenStack Monasca-events-api, consult the
documentation available online at:

* `Installation <https://docs.openstack.org/monasca-events-api/latest/install/>`_
* `Configuration <https://docs.openstack.org/monasca-events-api/latest/configuration/>`_

Bug tracking
------------

In the unfortunate event that bugs are discovered, they should
be reported to the appropriate bug tracker. If you obtained
the software from a 3rd party operating system vendor, it is
often wise to use their own bug tracker for reporting problems.
In all other cases use the master OpenStack bug tracker,
available at:

* `Storyboard <https://storyboard.openstack.org/#!/project/866>`_
